@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2024	PgPool Global Development Group
+ * Copyright (c) 2003-2023	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -41,14 +41,13 @@ typedef struct
 	bool		has_view;		/* True if view is used */
 	bool		has_function_call;	/* True if write function call is used */
 	int			pg_terminate_backend_pid;	/* pid argument of
-											 * pg_terminate_backedn_call(if
+											 * pg_terminate_backend_call(if
 											 * used) */
 	bool		has_non_immutable_function_call;	/* True if non immutable
 													 * functions are used */
 	bool		has_insertinto_or_locking_clause;	/* True if it has SELECT
 													 * INTO or FOR
 													 * SHARE/UPDATE */
-	bool		row_security;	/* true if row security enabled */
 	int			num_oids;		/* number of oids */
 	int			table_oids[POOL_MAX_SELECT_OIDS];	/* table oids */
 	char		table_names[POOL_MAX_SELECT_OIDS][NAMEDATALEN];	/* table names */
@@ -62,7 +61,6 @@ extern bool pool_has_temp_table(Node *node);
 extern void discard_temp_table_relcache(void);
 extern bool pool_has_unlogged_table(Node *node);
 extern bool pool_has_view(Node *node);
-extern bool pool_has_row_security(Node *node);
 extern bool pool_has_insertinto_or_locking_clause(Node *node);
 extern bool pool_has_pgpool_regclass(void);
 extern bool pool_has_to_regclass(void);
